@@ -12,7 +12,7 @@ def __get_filtered_copy(df: pd.DataFrame, include_transitions: bool, remove_no_l
     result = df.copy().drop(columns=['sequence'])
     result = result[result.label != -1] if  remove_no_labels else result
     result = result if include_transitions else result[result.label <= 6]
-    result = result if include_gyro else result[['acc-x', 'acc-y', 'acc-z']]
+    result = result if include_gyro else result[['acc-x', 'acc-y', 'acc-z', 'label']]
     return result
 
 
